<?php

namespace Litepie\Product\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litepie\Product\Http\Requests\ProductmodelRequest;
use Litepie\Product\Interfaces\ProductmodelRepositoryInterface;
use Litepie\Product\Models\Productmodel;

/**
 * Resource controller class for productmodel.
 */
class ProductmodelResourceController extends BaseController
{

    /**
     * Initialize productmodel resource controller.
     *
     * @param type ProductmodelRepositoryInterface $productmodel
     *
     * @return null
     */
    public function __construct(ProductmodelRepositoryInterface $productmodel)
    {
        parent::__construct();
        $this->repository = $productmodel;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Product\Repositories\Criteria\ProductmodelResourceCriteria::class);
    }

    /**
     * Display a list of productmodel.
     *
     * @return Response
     */
    public function index(ProductmodelRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litepie\Product\Repositories\Presenter\ProductmodelPresenter::class)
                ->$function();
        }

        $productmodels = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('product::productmodel.names'))
            ->view('product::productmodel.index', true)
            ->data(compact('productmodels', 'view'))
            ->output();
    }

    /**
     * Display productmodel.
     *
     * @param Request $request
     * @param Model   $productmodel
     *
     * @return Response
     */
    public function show(ProductmodelRequest $request, Productmodel $productmodel)
    {

        if ($productmodel->exists) {
            $view = 'product::productmodel.show';
        } else {
            $view = 'product::productmodel.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('product::productmodel.name'))
            ->data(compact('productmodel'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new productmodel.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ProductmodelRequest $request)
    {

        $productmodel = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('product::productmodel.name')) 
            ->view('product::productmodel.create', true) 
            ->data(compact('productmodel'))
            ->output();
    }

    /**
     * Create new productmodel.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ProductmodelRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $productmodel                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('product::productmodel.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('product/productmodel/' . $productmodel->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/product/productmodel'))
                ->redirect();
        }

    }

    /**
     * Show productmodel for editing.
     *
     * @param Request $request
     * @param Model   $productmodel
     *
     * @return Response
     */
    public function edit(ProductmodelRequest $request, Productmodel $productmodel)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('product::productmodel.name'))
            ->view('product::productmodel.edit', true)
            ->data(compact('productmodel'))
            ->output();
    }

    /**
     * Update the productmodel.
     *
     * @param Request $request
     * @param Model   $productmodel
     *
     * @return Response
     */
    public function update(ProductmodelRequest $request, Productmodel $productmodel)
    {
        try {
            $attributes = $request->all();

            $productmodel->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('product::productmodel.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('product/productmodel/' . $productmodel->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('product/productmodel/' . $productmodel->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the productmodel.
     *
     * @param Model   $productmodel
     *
     * @return Response
     */
    public function destroy(ProductmodelRequest $request, Productmodel $productmodel)
    {
        try {

            $productmodel->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('product::productmodel.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('product/productmodel/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('product/productmodel/' . $productmodel->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple productmodel.
     *
     * @param Model   $productmodel
     *
     * @return Response
     */
    public function delete(ProductmodelRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('product::productmodel.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('product/productmodel'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/product/productmodel'))
                ->redirect();
        }

    }

    /**
     * Restore deleted productmodels.
     *
     * @param Model   $productmodel
     *
     * @return Response
     */
    public function restore(ProductmodelRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('product::productmodel.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/product/productmodel'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/product/productmodel/'))
                ->redirect();
        }

    }

}
